# TAuth - **T**eia **Auth**entication Service

TAuth intro.

## Quick Links

- [Installation](./getting_started/installation.md)
- [Quick Start](./getting_started/quickstart.md)
- [API Reference][tauth]
- GitHub Repository
- PyPI Package
- ...
